@@ -177,8 +177,8 @@ XsldbgEventData *XsldbgEvent::createEventData(XsldbgMessageEnum type, const void
       handleLineNoChanged(result, msgData);
       break;
 
-    case XSLDBG_MSG_FILE_CHANGED:    /* 10: Loaded source/data file */
-
+    case XSLDBG_MSG_FILE_CHANGED:    /* 10: Changed selection for source/data/output file */
+	// not used 
       break;
 
     case XSLDBG_MSG_BREAKPOINT_CHANGED:      /* 11: Response to a showbreak command */
@@ -357,7 +357,11 @@ void XsldbgEvent::emitMessage(XsldbgEventData *eventData)
       break;
 
     case XSLDBG_MSG_FILE_CHANGED:    /* 10: Loaded source/data file */
-      /* not used */
+	if (beenCreated == false){
+	    /* Empty data */
+	}else{
+	    emit debugger->fileDetailsChanged();
+	}
       break;
 
     case XSLDBG_MSG_BREAKPOINT_CHANGED:      /* 11: Response to a showbreak command */
@@ -508,7 +512,7 @@ void XsldbgEvent::handleGlobalVariableItem(XsldbgEventData *eventData, const  vo
       /* add our specific data to eventData*/
       if (msgData != 0L){
 	xsltStackElemPtr item = (xsltStackElemPtr)msgData;
-	QString name, fileName;
+	QString name, fileName, selectXPath;
 	int lineNumber = -1;
 
 	/* variable name*/
@@ -522,16 +526,25 @@ void XsldbgEvent::handleGlobalVariableItem(XsldbgEventData *eventData, const  vo
 	  fileName = XsldbgDebuggerBase::fromUTF8FileName(item->comp->inst->doc->URL);
 	  lineNumber= xmlGetLineNo(item->comp->inst);
 	}
+	
+	if (item->select)
+	    selectXPath   = XsldbgDebuggerBase::fromUTF8(item->select);
 
-	eventData->setText(0, name);
-	eventData->setText(1, fileName);
-	eventData->setInt(0, lineNumber);
+	  eventData->setText(0, name);
+	  eventData->setText(1, "");
+	  eventData->setText(2, fileName);
+	  eventData->setText(3, selectXPath);
+	  eventData->setInt(0, lineNumber);
+	  eventData->setInt(1, 0); 
       }
     }else{
       /* emit the event data via debugger*/
-      emit debugger->globalVariableItem(eventData->getText(0), /* variable name*/
-					eventData->getText(1), /* file name*/
-					eventData->getInt(0) /* line number */);
+      emit debugger->variableItem(eventData->getText(0), /* variable name*/
+				       eventData->getText(1), /* templatecontext*/
+				       eventData->getText(2), /* file name */
+				       eventData->getInt(0), /* line number */
+				       eventData->getText(3), /* select XPath */
+				       eventData->getInt(1) /* Is this a local variable */ );
     }
   }
 }
@@ -544,7 +557,7 @@ void XsldbgEvent::handleLocalVariableItem(XsldbgEventData *eventData, const  voi
       /* add our specific data to eventData*/
       if (msgData != 0L){
 	xsltStackElemPtr item = (xsltStackElemPtr)msgData;
-	QString name, templateContext, fileName;
+	QString name, templateContext, fileName, selectXPath;
 	int lineNumber = -1;
 	xmlNodePtr varXmlNode;
 
@@ -575,20 +588,26 @@ void XsldbgEvent::handleLocalVariableItem(XsldbgEventData *eventData, const  voi
 	    fileName = XsldbgDebuggerBase::fromUTF8FileName(varXmlNode->doc->URL);
 	    lineNumber = xmlGetLineNo(varXmlNode);
 	  }
+	
+	  if (item->select)
+		selectXPath   = XsldbgDebuggerBase::fromUTF8(item->select);
 
 	  eventData->setText(0, name);
 	  eventData->setText(1, templateContext);
 	  eventData->setText(2, fileName);
+	  eventData->setText(3, selectXPath);
 	  eventData->setInt(0, lineNumber);
-
+	  eventData->setInt(1, 1);
 	}
       }
     }else{
       /* emit the event data via debugger*/
-      emit debugger->localVariableItem(eventData->getText(0), /* variable name*/
+      emit debugger->variableItem(eventData->getText(0), /* variable name*/
 				       eventData->getText(1), /* templatecontext*/
 				       eventData->getText(2), /* file name */
-				       eventData->getInt(0) /* line number */);
+				       eventData->getInt(0), /* line number */
+				       eventData->getText(3), /* select XPath */
+				       eventData->getInt(1) /* Is this a local variable */ );
     }
   }
 }
