@@ -34,12 +34,58 @@
 
 QString QExtFileInfo::lastErrorMsg = "";
 
-/** create a relative short url based in baseURL*/
-KURL QExtFileInfo::toRelative(const KURL& urlToConvert,const KURL& baseURL)
+QString QExtFileInfo::canonicalPath(const QString& path)
 {
+  if (!path.startsWith("/") || path == "/")
+    return path;
+  bool endsWithSlash = path.endsWith("/");
+  QDir dir(path);
+  if (dir.exists() || QFileInfo(path).exists())
+  {
+    QString s = dir.canonicalPath();
+    if (endsWithSlash)
+      s.append("/");
+    return s;
+  } else
+  {
+    KURL u = KURL::fromPathOrURL(path).upURL();
+    QString s = u.path(-1) + "/";
+    if (s == "//") s = "/";
+    QString s2 = path.mid(s.length());
+    s2 = QExtFileInfo::canonicalPath(s) + s2;
+    return s2;
+  }
+}
+
+QString QExtFileInfo::homeDirPath()
+{
+  return QDir(QDir::homeDirPath()).canonicalPath();
+}
+
+/** create a relative short url based in baseURL*/
+KURL QExtFileInfo::toRelative(const KURL& _urlToConvert,const KURL& _baseURL, bool resolveSymlinks)
+{
+  KURL urlToConvert = _urlToConvert;
+  KURL baseURL = _baseURL;
   KURL resultURL = urlToConvert;
   if (urlToConvert.protocol() == baseURL.protocol())
   {
+    if (urlToConvert.isLocalFile())
+    {
+      QString path;
+      if (resolveSymlinks)
+        path = QExtFileInfo::canonicalPath(urlToConvert.path());
+      else
+        path = urlToConvert.path();
+      if (!path.isEmpty())
+        urlToConvert.setPath(path);
+      if (resolveSymlinks)
+        path = QExtFileInfo::canonicalPath(baseURL.path());
+      else
+        path = baseURL.path();
+      if (!path.isEmpty())
+        baseURL.setPath(path);
+    }
     QString path = urlToConvert.path();
     QString basePath = baseURL.path(1);
     if (path.startsWith("/"))
@@ -80,11 +126,20 @@ KURL QExtFileInfo::toRelative(const KURL& urlToConvert,const KURL& baseURL)
   return resultURL;
 }
 /** convert relative filename to absolute */
-KURL QExtFileInfo::toAbsolute(const KURL& urlToConvert,const KURL& baseURL)
+KURL QExtFileInfo::toAbsolute(const KURL& _urlToConvert,const KURL& _baseURL)
 {
+  KURL urlToConvert = _urlToConvert;
+  KURL baseURL = _baseURL;
   KURL resultURL = urlToConvert;
+
   if (urlToConvert.protocol() == baseURL.protocol() && !urlToConvert.path().startsWith("/"))
   {
+    if (urlToConvert.isLocalFile())
+    {
+      QString path = QExtFileInfo::canonicalPath(baseURL.path());
+      if (!path.isEmpty())
+        baseURL.setPath(path);
+    }
     int pos;
     QString cutname = urlToConvert.path();
     QString cutdir = baseURL.path(1);
@@ -112,7 +167,7 @@ KURL::List QExtFileInfo::allFiles( const KURL& path, const QString& mask, QWidge
   return internalFileInfo.allFilesInternal(path, mask, window);
 }
 
-KURL::List QExtFileInfo::allFilesRelative( const KURL& path, const QString& mask, QWidget *window)
+KURL::List QExtFileInfo::allFilesRelative( const KURL& path, const QString& mask, QWidget *window, bool resolveSymlinks)
 {
   QExtFileInfo internalFileInfo;
   KURL::List r = internalFileInfo.allFilesInternal(path, mask, window);
@@ -120,7 +175,7 @@ KURL::List QExtFileInfo::allFilesRelative( const KURL& path, const QString& mask
   KURL::List::Iterator it;
   for ( it = r.begin(); it != r.end(); ++it )
   {
-    *it = QExtFileInfo::toRelative( *it, path );
+    *it = QExtFileInfo::toRelative( *it, path, resolveSymlinks );
   }
 
   return r;
@@ -132,36 +187,39 @@ QDict<KFileItem> QExtFileInfo::allFilesDetailed(const KURL& path, const QString&
   return internalFileInfo.allFilesDetailedInternal(path, mask, window);
 }
 
+
 bool QExtFileInfo::createDir(const KURL& path, QWidget *window)
 {
   int i = 0;
   bool result;
+  KURL dir3; 
   KURL dir2;
   KURL dir1 = path;
   dir1.setPath("/");
-  if (!exists(dir1, window))
+  if (!exists(dir1, false, window))
   {
     return false; //the root is not accessible, possible wrong username/password supplied
   }
-  while (!exists(path, window) && dir2.path() != path.path())
+  while (!exists(path, false, window) && dir2.path() != path.path())
   {
     dir1 = path;
     dir2 = path;
 
     dir1=cdUp(dir1);
-    while (!exists(dir1, window) && dir1.path() != "/")
+    while (!exists(dir1, false, window) && dir1.path() != "/")
     {
       dir1 = cdUp(dir1);
       dir2 = cdUp(dir2);
     //  debug(d1);
     }
-  //  dir2.setPath(dir2.path(-1));
-    result = KIO::NetAccess::mkdir(dir2, window);
-    if (dir2.path() == "/")
+    dir3 = dir2;
+    dir3.adjustPath(-1); //some servers refuse to create directories ending with a slash
+    result = KIO::NetAccess::mkdir(dir3, window);
+    if (dir2.path() == "/" || !result)
       break;
     i++;
   }
- result = exists(path, window);
+ result = exists(path, false, window);
  return result;
 }
 
@@ -197,20 +255,20 @@ KURL QExtFileInfo::home()
 }
 
 
-bool QExtFileInfo::exists(const KURL& a_url, QWidget *window)
+bool QExtFileInfo::exists(const KURL& a_url, bool readingOnly, QWidget *window)
 {
 // Andras: Don't use it now, as it brings up an extra dialog and need manual
 // intervention when usign fish
 // return KIO::NetAccess::exists(a_url, false);
 
 // No dialog when stating.
- if ( a_url.isLocalFile() )
+ if (a_url.isLocalFile())
  {
-    return QFile::exists( a_url.path() );
+   return QFile::exists(a_url.path());
  } else
  {
-  QExtFileInfo internalFileInfo;
-  return internalFileInfo.internalExists(a_url, window);
+   QExtFileInfo internalFileInfo;
+   return internalFileInfo.internalExists(a_url, readingOnly, window);
  }
 }
 
@@ -225,8 +283,11 @@ bool QExtFileInfo::copy( const KURL& src, const KURL& target, int permissions,
 /** No descriptions */
 KURL::List QExtFileInfo::allFilesInternal(const KURL& startURL, const QString& mask, QWidget *window)
 {
+  if (startURL.isLocalFile())
+    return allLocalFiles(startURL.path(-1), mask);
+
   dirListItems.clear();
-  if (internalExists(startURL, window))
+  if (internalExists(startURL, true, window))
   {
     lstFilters.setAutoDelete(true);
     lstFilters.clear();
@@ -264,7 +325,7 @@ QDict<KFileItem> QExtFileInfo::allFilesDetailedInternal(const KURL& startURL, co
   detailedDirListItems.setAutoDelete(true);
   detailedDirListItems.clear();
   detailedDirListItems.setAutoDelete(false);
-  if (internalExists(startURL, window))
+  if (internalExists(startURL, true, window))
   {
     lstFilters.setAutoDelete(true);
     lstFilters.clear();
@@ -295,10 +356,38 @@ QDict<KFileItem> QExtFileInfo::allFilesDetailedInternal(const KURL& startURL, co
   return detailedDirListItems;
 }
 
+KURL::List QExtFileInfo::allLocalFiles(const QString& startPath, const QString& mask)
+{
+  KURL::List list;
+  QDir d(startPath, mask);
+  QStringList l = d.entryList();
+  QStringList::ConstIterator end = l.constEnd();
+  QString path;
+  for (QStringList::ConstIterator it = l.constBegin(); it != end; ++it)
+  {
+    path = *it;
+    if (path != "." && path != "..")
+    {
+      path = startPath + "/" + path;
+      if (QFileInfo(path).isDir())
+        path.append("/");
+      list.append(KURL::fromPathOrURL(path));
+    }
+  }
+  l = d.entryList("*", QDir::Dirs);
+  end = l.constEnd();
+  for (QStringList::ConstIterator it = l.constBegin(); it != end; ++it)
+  {
+    if ((*it) != "." && (*it) != "..")
+      list += allLocalFiles(startPath + "/" + (*it), mask);
+  }
+  return list;
+}
+
 
 //Some hackery from KIO::NetAccess as they do not do exactly what we want
 /* return true if the url exists*/
-bool QExtFileInfo::internalExists(const KURL& url, QWidget *window)
+bool QExtFileInfo::internalExists(const KURL& url, bool readingOnly, QWidget *window)
 {
   bJobOK = true;
   KURL url2 = url;
@@ -307,7 +396,7 @@ bool QExtFileInfo::internalExists(const KURL& url, QWidget *window)
   KIO::StatJob * job = KIO::stat(url2, false);
   job->setWindow(window);
   job->setDetails(0);
-  job->setSide(false); //check the url for writing
+  job->setSide(readingOnly);
   connect( job, SIGNAL( result (KIO::Job *) ),
            this, SLOT( slotResult (KIO::Job *) ) );
 
@@ -412,14 +501,22 @@ void QExtFileInfo::slotNewEntries(KIO::Job *job, const KIO::UDSEntryList& udsLis
       if (item->isDir() && item->isLink())
       {
         KURL u = item->url();
-        u.setPath(item->linkDest());
+        QString linkDest = item->linkDest();
+        kdDebug(24000) << "Got link: " << name << " Points to:" << linkDest << endl;
+        if (linkDest.startsWith("."))
+        {
+          u.setPath(u.directory(false, true) + linkDest);
+          u.cleanPath();
+        }
+        else       
+          u.setPath(linkDest);
         u.adjustPath(+1);
-        if (!dirListItems.contains(u) && u.url() != m_listStartURL)
+        if (!dirListItems.contains(u) && u.url() != m_listStartURL && !u.isParentOf(item->url()))
         {
           linkItems.append(new KFileItem(*item));
         } else
         {
-          kdDebug(24000) << "Recursive link" << u.url() << endl;
+          kdDebug(24000) << "Recursive link " << u.url() << endl;
           continue;
         }
       }
